@@ -10,7 +10,7 @@ import se
 import se.typography
 
 
-def british2american() -> int:
+def british2american(plain_output: bool) -> int:
 	"""
 	Entry point for `se british2american`
 	"""
@@ -24,9 +24,13 @@ def british2american() -> int:
 	return_code = 0
 	console = Console(highlight=False, theme=se.RICH_THEME, force_terminal=se.is_called_from_parallel()) # Syntax highlighting will do weird things when printing paths; force_terminal prints colors when called from GNU Parallel
 
-	for filename in se.get_target_filenames(args.targets, (".xhtml",)):
+	for filename in se.get_target_filenames(args.targets, ".xhtml"):
+		# Skip the uncopyright, since it contains quotes but is a fixed file
+		if filename.name == "uncopyright.xhtml":
+			continue
+
 		if args.verbose:
-			console.print(f"Processing [path][link=file://{filename}]{filename}[/][/] ...", end="")
+			console.print(se.prep_output(f"Processing [path][link=file://{filename}]{filename}[/][/] ...", plain_output), end="")
 
 		try:
 			with open(filename, "r+", encoding="utf-8") as file:
@@ -39,7 +43,7 @@ def british2american() -> int:
 						convert = False
 						if args.verbose:
 							console.print("")
-						se.print_error(f"File appears to already use American quote style, ignoring. Use [bash]--force[/] to convert anyway.{f' File: [path][link=file://{filename}]{filename}[/][/]' if not args.verbose else ''}", args.verbose, True)
+						se.print_error(f"File appears to already use American quote style, ignoring. Use [bash]--force[/] to convert anyway.{f' File: [path][link=file://{filename}]{filename}[/][/]' if not args.verbose else ''}", args.verbose, plain_output=plain_output)
 
 				if convert:
 					new_xhtml = se.typography.convert_british_to_american(xhtml)
@@ -50,7 +54,7 @@ def british2american() -> int:
 						file.truncate()
 
 		except FileNotFoundError:
-			se.print_error(f"Couldn’t open file: [path][link=file://{filename}]{filename}[/][/].")
+			se.print_error(f"Couldn’t open file: [path][link=file://{filename}]{filename}[/][/].", plain_output=plain_output)
 			return_code = se.InvalidInputException.code
 
 	return return_code
