@@ -50,75 +50,79 @@ def semanticate(xhtml: str) -> str:
 	"""
 
 	# Some common abbreviations
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mr\.", r"<abbr>Mr.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mrs\.", r"<abbr>Mrs.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Ms\.", r"<abbr>Ms.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Dr\.", r"<abbr>Dr.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Drs\.", r"<abbr>Drs.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Prof\.", r"<abbr>Prof.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Rev\.", r"<abbr>Rev.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Hon\.", r"<abbr>Hon.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Lieut\.", r"<abbr>Lieut.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Fr\.", r"<abbr>Fr.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Lt\.", r"<abbr>Lt.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Capt\.", r"<abbr>Capt.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Pvt\.", r"<abbr>Pvt.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Esq\.", r"<abbr>Esq.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Bros\.", r"<abbr>Bros.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mt\.", r"<abbr>Mt.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)MM\.", r"<abbr>MM.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mme\.", r"<abbr>Mme.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mmes\.", r"<abbr>Mmes.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mon\.", r"<abbr>Mon.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mlle\.", r"<abbr>Mlle.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mdlle\.", r"<abbr>Mdlle.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Mlles\.", r"<abbr>Mlles.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Messrs\.", r"<abbr>Messrs.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Messers\.", r"<abbr>Messers.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Vv])ol(s?)\.", r"<abbr>\1ol\2.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Cc])hap\. ([0-9])", r"<abbr>\1hap.</abbr> \2", xhtml) # The number allows us to avoid phrases like `Hello, old chap.`
-	xhtml = regex.sub(r"(?<!\<abbr[^\>]*?\>)(P\.(?:P\.)?S\.(?:S\.)?)", r"""<abbr epub:type="z3998:initialism">\1</abbr>""", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Co\.", r"<abbr>Co.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Inc\.", r"<abbr>Inc.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Ltd\.", r"<abbr>Ltd.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)St\.", r"<abbr>St.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Gg])ov\.", r"<abbr>\1ov.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)Col\.", r"<abbr>Col.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)MS(S?)\.", r"""<abbr>MS\1.</abbr>""", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Vv])iz\.", r"<abbr>\1iz.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)etc\.", r"<abbr>etc.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Cc])f\.", r"<abbr>\1f.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)p(p?)\.([\s0-9])", r"<abbr>p\1.</abbr>\2", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)ed\.", r"<abbr>ed.</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)(Jan\.|Feb\.|Mar\.|Apr\.|Jun\.|Jul\.|Aug\.|Sep\.|Sept\.|Oct\.|Nov\.|Dec\.)", r"<abbr>\1</abbr>", xhtml)
-	xhtml = regex.sub(r"(?<!\<abbr\>)No\.(\s+[0-9]+)", r"<abbr>No.</abbr>\1", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Vv])s\.", r"<abbr>\1s.</abbr>", xhtml)
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Ff])f\.", r"<abbr>\1f.</abbr>", xhtml) # ff. typically used in footnotes, means "and following"
-	xhtml = regex.sub(r"\b(?<!\<abbr\>)([Ll])ib\.", r"<abbr>\1ib.</abbr>", xhtml) # Lib. = Liber = Book
-	# python allows a variable lookbehind with the ( eoc)?; HOWEVER, it counts it as the
-	#	first capture group, so if there are one or more capture groups in the regex itself,
-	#	be sure to start at 2 when specifying the group(s) in the replacement spec.
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)([Ii])\.e\.""", r"""<abbr epub:type="z3998:initialism">\2.e.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)([Ee])\.g\.""", r"""<abbr epub:type="z3998:initialism">\2.g.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)\bN\.?B\.\b""", r"""<abbr epub:type="z3998:initialism">N.B.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:name-title"( class="eoc")?\>)Ph\.?\s*D\.?""", r"""<abbr epub:type="z3998:name-title">Ph. D.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)I\.?O\.?U\.?\b""", r"""<abbr epub:type="z3998:initialism">I.O.U.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(\s)(?<!\<abbr epub:type="se:era"\>)A\.?D""", r"""\1<abbr epub:type="se:era">AD</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(\s)(?<!\<abbr epub:type="se:era"( class="eoc")?\>)B\.?C""", r"""\1<abbr epub:type="se:era">BC</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr( class="eoc")?\>)([ap])\.\s?m\.""", r"""<abbr>\2.m.</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:given-name"( class="eoc")?\>)(Thos\.|Jas\.|Chas\.)""", r"""<abbr epub:type="z3998:given-name">\2</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)T\.?V\.?\b""", r"""<abbr epub:type="z3998:initialism">TV</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)S\.?O\.?S\.?\b""", r"""<abbr epub:type="z3998:initialism">SOS</abbr>""", xhtml)
-	xhtml = regex.sub(r"""(?<!\<abbr epub:type="z3998:initialism"( class="eoc")?\>)\b([1-4]D)\b""", r"""<abbr epub:type="z3998:initialism">\2</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mr\.", r"<abbr>Mr.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mrs\.", r"<abbr>Mrs.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Ms\.", r"<abbr>Ms.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Dr\.", r"<abbr>Dr.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Drs\.", r"<abbr>Drs.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Prof\.", r"<abbr>Prof.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Rev\.", r"<abbr>Rev.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Hon\.", r"<abbr>Hon.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Lieut\.", r"<abbr>Lieut.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Fr\.", r"<abbr>Fr.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Lt\.", r"<abbr>Lt.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Capt\.", r"<abbr>Capt.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Pvt\.", r"<abbr>Pvt.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Esq\.", r"<abbr>Esq.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Bros\.", r"<abbr>Bros.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mt\.", r"<abbr>Mt.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))MM\.", r"<abbr>MM.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mme\.", r"<abbr>Mme.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mmes\.", r"<abbr>Mmes.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mon\.", r"<abbr>Mon.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mlle\.", r"<abbr>Mlle.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mdlle\.", r"<abbr>Mdlle.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Mlles\.", r"<abbr>Mlles.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Messrs\.", r"<abbr>Messrs.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Messers\.", r"<abbr>Messers.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Vv])ol(s?)\.", r"<abbr>\1ol\2.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Cc])hap\. ([0-9])", r"<abbr>\1hap.</abbr> \2", xhtml) # The number allows us to avoid phrases like `Hello, old chap.`
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>)|\.)(P\.(?:P\.)?S\.(?:S\.)?\B)", r"""<abbr epub:type="z3998:initialism">\1</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Co\.", r"<abbr>Co.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Inc\.", r"<abbr>Inc.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Ltd\.", r"<abbr>Ltd.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))St\.", r"<abbr>St.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Gg])ov\.", r"<abbr>\1ov.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Col\.", r"<abbr>Col.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))MS(S?)\.", r"""<abbr>MS\1.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Vv])iz\.", r"<abbr>\1iz.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))etc\.", r"<abbr>etc.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Cc])f\.", r"<abbr>\1f.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))ed\.", r"<abbr>ed.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(Jan\.|Feb\.|Mar\.|Apr\.|Jun\.|Jul\.|Aug\.|Sep\.|Sept\.|Oct\.|Nov\.|Dec\.)", r"<abbr>\1</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))No\.(\s+[0-9]+)", r"<abbr>No.</abbr>\1", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Vv])s\.", r"<abbr>\1s.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Ff])f\.", r"<abbr>\1f.</abbr>", xhtml) # ff. typically used in footnotes, means "and following"
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Ll])ib\.", r"<abbr>\1ib.</abbr>", xhtml) # Lib. = Liber = Book
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Ii])\.e\.", r"""<abbr epub:type="z3998:initialism">\1.e.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([Ee])\.g\.", r"""<abbr epub:type="z3998:initialism">\1.g.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))\bN\.?B\.\B", r"""<abbr epub:type="z3998:initialism">N.B.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))Ph\.?\s*D\.?", r"""<abbr epub:type="z3998:name-title">Ph. D.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(?:IOU(?:\.|\b)|I\.O\.U\.)", r"""<abbr epub:type="z3998:initialism">I.O.U.</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))\b([1-4]D)\b", r"""<abbr epub:type="z3998:initialism">\1</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(Thos\.|Jas\.|Chas\.|Wm\.)", r"""<abbr epub:type="z3998:given-name">\1</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([ap])\.\s?m\.", r"<abbr>\1.m.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([0-9]{1,2})\s?[Aa]\.?\s?[Mm](?:\.|\b)", r"\1 <abbr>a.m.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))([0-9]{1,2})\s?[Pp]\.?\s?[Mm](?:\.|\b)", r"\1 <abbr>p.m.</abbr>", xhtml)
+    # this should be placed after the am/pm test, to prevent tagging just the p. in "p. m."
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))p(p?)\.([\s0-9])", r"<abbr>p\1.</abbr>\2", xhtml)
+    # keep a period after TV that terminates a clause
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))T\.?V\.([”’]?</p>|\s+[“‘]?[\p{Uppercase_Letter}])", r"""<abbr epub:type="z3998:initialism">TV</abbr>.\1""", xhtml)
+    # otherwise, get rid of any periods in TV
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(?:TV\b|T\.V\.\B)", r"""<abbr epub:type="z3998:initialism">TV</abbr>""", xhtml)
+    # keep a period after AD/BC that terminates a clause
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))A\.?D\.([”’]?</p>|\s+[“‘]?[\p{Uppercase_Letter}])", r"""<abbr epub:type="se:era">AD</abbr>.\1""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))B\.?C\.([”’]?</p>|\s+[“‘]?[\p{Uppercase_Letter}])", r"""<abbr epub:type="se:era">BC</abbr>.\1""", xhtml)
+    # otherwise, get rid of any periods in AD/BC
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(?:AD\b|A\.D\.\B)", r"""<abbr epub:type="se:era">AD</abbr>""", xhtml)
+	xhtml = regex.sub(r"(?<!(?:\.|\B|\<abbr[^>]*?\>))(?:BC\b|B\.C\.\B)", r"""<abbr epub:type="se:era">BC</abbr>""", xhtml)
 
 	# Wrap £sd shorthand
 	xhtml = regex.sub(r"([0-9½¼⅙⅚⅛⅜⅝]+)([sd⅞]\.)", r"\1<abbr>\2</abbr>", xhtml)
 
-	# Guess at adding eoc (End Of Clause) class
-	xhtml = regex.sub(r"""<abbr>([\p{Letter}\.]+?\.)</abbr></p>""", r"""<abbr class="eoc">\1</abbr></p>""", xhtml)
-	xhtml = regex.sub(r"""<abbr class="(.+?)">([\p{Letter}\.]+?\.)</abbr></p>""", r"""<abbr class="\1 eoc">\2</abbr></p>""", xhtml)
-	xhtml = regex.sub(r"""<abbr>etc\.</abbr>(\s+[\p{Uppercase_Letter}])""", r"""<abbr class="eoc">etc.</abbr>\1""", xhtml)
-	xhtml = regex.sub(r"""<abbr>etc\.</abbr>(”?)</p>""", r"""<abbr class="eoc">etc.</abbr>\1</p>""", xhtml)
+	# add eoc (End Of Clause) class
+	xhtml = regex.sub(r"<abbr>etc\.</abbr>([”’]?(?:</p>|\s+[“‘]?[\p{Uppercase_Letter}]))", r"""<abbr class="eoc">etc.</abbr>\1""", xhtml)
+	xhtml = regex.sub(r"""<abbr( epub:type="[^"]+")?>([^<]+\.)</abbr>([”’]?</p>)""", r"""<abbr class="eoc"\1>\2</abbr>\3""", xhtml)
 
 	# We may have added eoc classes twice, so remove duplicates here
 	xhtml = regex.sub(r"""<abbr class="(.*) eoc(\s+eoc)+">""", r"""<abbr class="\1 eoc">""", xhtml)
@@ -145,7 +149,10 @@ def semanticate(xhtml: str) -> str:
 	xhtml = regex.sub(r"([0-9]+)\s*([cmk][mgl])\b", fr"\1{se.NO_BREAK_SPACE}<abbr>\2</abbr>", xhtml)
 
 	# Add abbrevations around Imperial measurements
-	xhtml = regex.sub(r"(?<![\$£0-9,])([0-9½¼⅙⅚⅛⅜⅝⅞]+)\s*(ft|in|yd|mi|pt|qt|gal|oz|lbs)\.?\b", fr"\1{se.NO_BREAK_SPACE}<abbr>\2.</abbr>", xhtml)
+	xhtml = regex.sub(r"(?<![\$£0-9,])([0-9½¼⅙⅚⅛⅜⅝⅞]+)\s*(ft|yd|mi|pt|qt|gal|oz|lbs)\.?\b", fr"\1{se.NO_BREAK_SPACE}<abbr>\2.</abbr>", xhtml)
+
+	# Handle `in.` separately to require a period, because with an optional period there are too many false positives
+	xhtml = regex.sub(r"(?<![\$£0-9,])([0-9½¼⅙⅚⅛⅜⅝⅞]+)\s*in\.(\b|\s)", fr"\1{se.NO_BREAK_SPACE}<abbr>in.</abbr>", xhtml)
 
 	# Fix some possible errors introduced by the above
 	xhtml = regex.sub(fr"((?:[Nn]o\.|[Nn]umber)\s[0-9]+){se.NO_BREAK_SPACE}<abbr>in\.</abbr>", r"\1 in", xhtml)
@@ -1047,6 +1054,9 @@ def titlecase(text: str) -> str:
 	# So, convert to all lowercase first.
 	text = text.lower()
 
+	# Replace all white space except hair space with a space character
+	text = regex.sub(fr"[^\S{se.HAIR_SPACE}]+", " ", text)
+
 	text = pip_titlecase(text)
 
 	# We make some additional adjustments here
@@ -1055,13 +1065,14 @@ def titlecase(text: str) -> str:
 	# since they're typically lowercased anyway. (Except for things like `alt`, but we won't be titlecasing images!)
 	text = regex.sub(r"<(/?)([^>]+?)>", lambda result: "<" + result.group(1) + result.group(2).lower() + ">", text)
 
-	# Uppercase Roman numerals, but only if they are valid Roman numerals and they are not "MIX" (which is much more likely to be an English word than a Roman numeral
+	# Uppercase Roman numerals, but only if they are valid Roman numerals and they are not `MIX` (which is much more likely to be an English word than a Roman numeral)
+	# or `DI` which may be an Italian word
 	try:
-		text = regex.sub(r"(\s)([ivxlcdm]+)(\b)", lambda result: result.group(1) + result.group(2).upper() + result.group(3) if result.group(2).upper() != "MIX" and roman.fromRoman(result.group(2).upper()) else result.group(1) + result.group(2), text, flags=regex.IGNORECASE)
+		text = regex.sub(r"(\s)([ivxlcdm]+)(\b)", lambda result: result.group(1) + result.group(2).upper() + result.group(3) if result.group(2).upper() not in ("MIX", "DI") and roman.fromRoman(result.group(2).upper()) else result.group(1) + result.group(2), text, flags=regex.IGNORECASE)
 	except roman.InvalidRomanNumeralError:
 		pass
 
-	# Lowercase "and" and "or", even if preceded by punctuation
+	# Lowercase `and`, `or` even if preceded by punctuation
 	text = regex.sub(r"([^\p{Letter}]) (And|Or)\b", lambda result: result.group(1) + " " + result.group(2).lower(), text)
 
 	# pip_titlecase capitalizes *all* prepositions preceded by parenthesis; we only want to capitalize ones that *aren't the first word of a subtitle*
@@ -1072,44 +1083,47 @@ def titlecase(text: str) -> str:
 	# Uppercase words preceded by en or em dash
 	text = regex.sub(fr"([—–]{se.WORD_JOINER}?)([\p{{Lowercase_Letter}}])", lambda result: result.group(1) + result.group(2).upper(), text)
 
-	# Lowercase "and", if it's not the very first word, and not preceded by an em-dash
+	# Lowercase `and`, if it's not the very first word, and not preceded by an em-dash
 	text = regex.sub(r"(?<!^)\bAnd\b", r"and", text)
 
+	# Lowercase `the`, if preceded by a dash (like `Puss-in-Boots` or `Jack-in-the-Box`)
+	text = regex.sub(r"\b(-)(In|The|Sur|Of|Au)\b", lambda result: result.group(1) + result.group(2).lower(), text)
+
 	# Lowercase "in", if followed by a semicolon (but not words like "inheritance")
 	text = regex.sub(r"\b; In\b", "; in", text)
 
-	# Lowercase th’, sometimes used poetically
+	# Lowercase `th’`, sometimes used poetically
 	text = regex.sub(r"\b Th’ \b", " th’ ", text)
 
-	# Lowercase o’
+	# Lowercase `o’`
 	text = regex.sub(r"\b O’ \b", " o’ ", text)
 
-	# Uppercase words that begin compound words, like "to-night" (which might appear in poetry)
+	# Uppercase words that begin compound words, like `to-night` (which might appear in poetry)
 	text = regex.sub(r" ([\p{Lowercase_Letter}])([\p{Lowercase_Letter}]+\-)", lambda result: " " + result.group(1).upper() + result.group(2), text)
 
-	# Lowercase "from", "with", as long as they're not the first word and not preceded by a parenthesis
+	# Lowercase `from`, `with`, as long as they're not the first word and not preceded by a parenthesis
 	text = regex.sub(r"(?<!^)(?<!\()\b(From|With)\b", lambda result: result.group(1).lower(), text)
 
 	# Capitalise the first word after an opening quote or italicisation that signifies a work
 	text = regex.sub(r"(‘|“|<i.*?epub:type=\".*?se:.*?\".*?>)([\p{Lowercase_Letter}])", lambda result: result.group(1) + result.group(2).upper(), text)
 
-	# Lowercase "the" if preceded by "vs."
+	# Lowercase `the` if preceded by `vs.`
 	text = regex.sub(r"(?:vs\.) The\b", "vs. the", text)
 
-	# Lowercase "de", "von", "van", "le", "du" as in "Charles de Gaulle", "Werner von Braun", etc., and if not the first word and not preceded by an &ldquo;
-	text = regex.sub(r"(?<!^|“)\b(Von|Van|Le|Des|De La|De|Du)\b", lambda result: result.group(1).lower(), text)
+	# Lowercase `de`, `von`, `van`, `le`, `du` as in `Charles de Gaulle`, `Werner von Braun`, etc., and if not the first word and not preceded by an &ldquo;
+	text = regex.sub(r"(?<!^|“)\b(Von|Van Der|Van|Le|\b[aA] La|\b[àÀ] La|Des|De La|De|Du|Di|Del)\b", lambda result: result.group(1).lower(), text)
 
-	# Uppercase word following "Or,", since it is probably a subtitle
+	# Uppercase word following `Or,`, since it is probably a subtitle
 	text = regex.sub(r"\bOr, ([\p{Lowercase_Letter}])", lambda result: "Or, " + result.group(1).upper(), text)
 
-	# Uppercase word following ":", except "or, ", which indicates a kind of subtitle
+	# Uppercase word following `:`, except `or, `, which indicates a kind of subtitle
 	text = regex.sub(r": ([\p{Lowercase_Letter}])(?!r, )", lambda result: ": " + result.group(1).upper(), text)
 
-	# Uppercase words after an initial contraction, like O'Keefe or L'Affaire. But only if there's at least 3 letters
-	# after, to prevent catching things like I'm or E're
+	# Uppercase words after an initial contraction, like `O'Keefe` or `L'Affaire`. But only if there's at least 3 letters
+	# after, to prevent catching things like `I'm` or `E're`
 	text = regex.sub(r"\b([\p{Uppercase_Letter}]’)([\p{Lowercase_Letter}])([\p{Letter}]{2,})", lambda result: result.group(1) + result.group(2).upper() + result.group(3), text)
 
-	# Uppercase letter after Mc
+	# Uppercase letter after `Mc`
 	text = regex.sub(r"\bMc([\p{Lowercase_Letter}])", lambda result: "Mc" + result.group(1).upper(), text)
 
 	# Uppercase first letter after beginning contraction
@@ -1118,25 +1132,34 @@ def titlecase(text: str) -> str:
 	# Uppercase first letter
 	text = regex.sub(r"^(\p{Lowercase_Letter}])", lambda result: result.group(1).upper(), text)
 
-	# Lowercase 'by'
+	# Lowercase `by`
 	text = regex.sub(r"(\s)By(\s|%)", lambda result: result.group(1) + "by" + result.group(2), text)
 
-	# Lowercase leading "d', as in "Marie d'Elle"
+	# Lowercase leading `d’`, as in `Marie d’Elle`
 	text = regex.sub(r"(?:\b|^)D’([\p{Letter}])", lambda result: "d’" + result.group(1).upper(), text)
 
-	# # Uppercase letter after leading "L', as in "L'Affaire"
+	# # Uppercase letter after leading `L'`, as in `L'Affaire`
 	# text = regex.sub(r"(?:\b|^)L’([\p{Letter}])", lambda result: "L’" + result.group(1).upper(), text)
 
+	# Uppercase `l’` as in `l’Affaire`, but not if it's a the first letter
+	text = regex.sub(r"(?<!^)L’([\p{Letter}])", lambda result: "l’" + result.group(1), text)
+
 	# Uppercase some known initialisms
 	text = regex.sub(r"(\s|^)(sos|md)(?:\b|$)", lambda result: result.group(1) + result.group(2).upper(), text, flags=regex.IGNORECASE)
 	text = regex.sub(r"(\s)(bc|ad)(?:\b|$)", lambda result: result.group(1) + result.group(2).upper(), text, flags=regex.IGNORECASE)
 
-	# Lowercase À (as in À La Carte) unless it's the first word
+	# Lowercase `À` (as in `À La Carte`) unless it's the first word
 	text = regex.sub(r"(?<!^)\bÀ\b", "à", text)
 
 	# Uppercase initialisms
 	text = regex.sub(r"\b(([\p{Letter}]\.)+)", lambda result: result.group(1).upper(), text)
 
+	# Uppercase No. as in Number
+	text = regex.sub(r"\b(no\.\s+)", lambda result: result.group(1).upper(), text)
+
+	# Lowercase V. as in versus in a legal case
+	text = regex.sub(r"\b(V\.\s+)", lambda result: result.group(1).lower(), text)
+
 	# Lowercase `mm` (millimeters, as in `50 mm gun`) unless it's followed by a period in which case it's likely `Mm.` (Monsieurs)
 	text = regex.sub(r"(\s)MM(\s|$)", r"\1mm\2", text)
 
@@ -1146,6 +1169,15 @@ def titlecase(text: str) -> str:
 	# Lowercase etc.
 	text = text.replace("Etc.", "etc.")
 
+	# Lowercase some special cases.
+	text = text.replace("A.B.C. Of", "A.B.C. of")
+
+	# More special cases
+	text = regex.sub(r"des Moines", "Des Moines", text)
+
+	# Like `Will-o’-the-Wisp`
+	text = regex.sub(r"(?<=-)(O’|The)-", lambda result: result.group(1).lower() + "-", text)
+
 	return text
 
 def make_url_safe(text: str) -> str:
@@ -1310,13 +1342,13 @@ def generate_title(xhtml: Union[str, EasyXmlTree]) -> str:
 		# Then after processing <hgroup>, the title becomes the 1st <hgroup> child;
 		# if there is a 2nd <hgroup> child after processing, add a colon and space, then the text of the 2nd <hgroup> child.
 		try:
-			title = regex.sub(r"\s+", " ", hgroup_element.xpath("./*[1]")[0].inner_text().strip())
+			title = regex.sub(r"\s+", " ", hgroup_element.xpath("./*[1]")[0].inner_text())
 		except Exception as ex:
 			raise se.InvalidSeEbookException("Couldn’t find title in [xhml]<hgroup>[/].") from ex
 
 		subtitle = hgroup_element.xpath("./*[2]")
 		if subtitle:
-			subtitle_text = subtitle[0].inner_text().strip()
+			subtitle_text = subtitle[0].inner_text()
 			title += f": {subtitle_text}"
 
 	else:
@@ -1330,7 +1362,7 @@ def generate_title(xhtml: Union[str, EasyXmlTree]) -> str:
 			for node in h_element.xpath("//*[contains(@epub:type, 'noteref')]"):
 				node.remove()
 
-			title = h_element.inner_text().strip()
+			title = h_element.inner_text()
 
 		else:
 			# No <h#> elements found. Try to get the title from the epub:type of the deepest <section> or <article> that has no <section> or <article> siblings. (Note the parenthesis
@@ -1358,4 +1390,7 @@ def generate_title(xhtml: Union[str, EasyXmlTree]) -> str:
 	# See https://stackoverflow.com/questions/3548949/how-can-i-exclude-some-characters-from-a-class
 	title = regex.sub(fr"[^\S{se.HAIR_SPACE}]+", " ", title)
 
+	# Unescape ampersands since we are returning a plain string, not XML
+	title = title.replace("&amp;", "&")
+
 	return title
