@@ -12,7 +12,7 @@ from typing import Dict, List, Optional, Tuple, Union
 from sys import getsizeof
 
 import git
-import lxml.etree as etree
+from lxml import etree
 from natsort import natsorted
 import regex
 
@@ -957,7 +957,8 @@ class SeEpub:
 					properties_attr = f" properties=\"{properties_attr}\""
 
 				# Add the manifest item
-				manifest.append(f"""<item href="{file_path.relative_to(self.content_path)}" id="{file_path.name}" media-type="{mime_type}"{properties_attr}/>""")
+				# Replace the path separator because if run on Windows we will get the wrong slash direction from pathlib
+				manifest.append(f"""<item href="{str(file_path.relative_to(self.content_path)).replace(os.sep, "/")}" id="{file_path.name}" media-type="{mime_type}"{properties_attr}/>""")
 
 		manifest = natsorted(manifest)
 
@@ -1113,7 +1114,7 @@ class SeEpub:
 
 		return self.metadata_dom.xpath("/package/metadata/dc:title/text()", True) or "WORK_TITLE"
 
-	def lint(self, skip_lint_ignore: bool) -> list:
+	def lint(self, skip_lint_ignore: bool, allowed_messages: List[str] = None) -> list:
 		"""
 		The lint() function is very big so for readability and maintainability
 		it's broken out to a separate file. Strictly speaking that file can be inlined
@@ -1122,7 +1123,7 @@ class SeEpub:
 
 		from se.se_epub_lint import lint # pylint: disable=import-outside-toplevel
 
-		return lint(self, skip_lint_ignore)
+		return lint(self, skip_lint_ignore, allowed_messages)
 
 	def build(self, run_epubcheck: bool, check_only: bool, build_kobo: bool, build_kindle: bool, output_directory: Path, proof: bool) -> None:
 		"""
@@ -1152,6 +1153,90 @@ class SeEpub:
 
 		return toc_xhtml
 
+	def _check_endnotes(self) -> list:
+		"""
+		Initial check to see if all note references in the body have matching endnotes
+		in endnotes.xhtml and no duplicates.
+
+		Returns string of failures if any. If these are empty, all was well.
+		"""
+		missing = []
+		duplicates = []
+		orphans = []
+		references = []
+		response = []
+		for file_path in self.spine_file_paths:
+			dom = self.get_dom(file_path)
+
+			for link in dom.xpath("/html/body//a[contains(@epub:type, 'noteref')]"):
+				anchor = ""
+				href = link.get_attr("href") or ""
+				if href:
+					# Extract just the anchor from a URL (ie, what follows a hash symbol)
+					hash_position = href.find("#") + 1  # we want the characters AFTER the hash
+					if hash_position > 0:
+						anchor = href[hash_position:]
+				references.append(anchor)  # keep these for later reverse check
+				# Now try to find anchor in endnotes
+				match_anchor = lambda x, old=anchor: x.anchor == old
+				matches = list(filter(match_anchor, self.endnotes))
+				if not matches:
+					missing.append(anchor)
+				if len(matches) > 1:
+					duplicates.append(anchor)
+		for miss in missing:
+			response.append(f"Missing endnote with anchor: {miss}")
+		for dupe in duplicates:
+			response.append(f"Duplicate endnotes with anchor: {dupe}")
+		# reverse check: look for orphaned endnotes
+		for note in self.endnotes:
+			# try to find it in our references collection
+			if note.anchor not in references:
+				orphans.append(note.anchor)
+		for orphan in orphans:
+			response.append(f"Orphan endnote with anchor: {orphan}")
+		return response
+
+	def recreate_endnotes(self) -> None:
+		"""
+		Renumber all noterefs starting from 1, and renumber all endnotes starting from 1.
+		Does not perform any sanity checks or do any rearranging; may result in more noterefs than endnotes, or more endnotes than noterefs.
+		Changes are written to disk.
+		"""
+
+		noteref_locations = {}
+
+		current_note_number = 1
+
+		# Renumber all noterefs starting from 1
+		for file_path in self.spine_file_paths:
+			dom = self.get_dom(file_path)
+
+			for node in dom.xpath("/html/body//a[contains(@epub:type, 'noteref')]"):
+				node.set_attr("href", f"endnotes.xhtml#note-{current_note_number}")
+				node.set_attr("id", f"noteref-{current_note_number}")
+				node.set_text(str(current_note_number))
+				noteref_locations[current_note_number] = file_path
+
+				current_note_number += 1
+
+			with open(file_path, "w") as file:
+				file.write(dom.to_string())
+
+		# Renumber all endnotes starting from 1
+		current_note_number = 1
+		endnotes_dom = self.get_dom(self.endnotes_path)
+		for node in endnotes_dom.xpath("/html/body//li[contains(@epub:type, 'endnote')]"):
+			node.set_attr("id", f"note-{current_note_number}")
+			for backlink in node.xpath(".//a[contains(@epub:type, 'backlink')]"):
+				filename = noteref_locations[current_note_number].name if current_note_number in noteref_locations else ""
+				backlink.set_attr("href", f"{filename}#noteref-{current_note_number}")
+
+			current_note_number += 1
+
+		with open(self.endnotes_path, "w") as file:
+			file.write(endnotes_dom.to_string())
+
 	def generate_endnotes(self) -> Tuple[int, int]:
 		"""
 		Read the epub spine to regenerate all endnotes in order of appearance, starting from 1.
@@ -1160,6 +1245,13 @@ class SeEpub:
 		Returns a tuple of (found_endnote_count, changed_endnote_count)
 		"""
 
+		# Do a safety check first, throw exception if it failed
+		results = self._check_endnotes()
+		if results:
+			report = "\n".join(results)
+			raise se.InvalidInputException(f"Endnote error(s) found: {report}.")
+
+		# If we get here, it's safe to proceed
 		processed = 0
 		current_note_number = 1
 		notes_changed = 0
@@ -1184,7 +1276,7 @@ class SeEpub:
 				with open(file_path, "w") as file:
 					file.write(se.formatting.format_xhtml(dom.to_string()))
 
-		# now process any endnotes WITHIN the endnotes
+		# Now process any endnotes WITHIN the endnotes
 		for source_note in self.endnotes:
 			node = source_note.node
 			needs_rewrite = False
